@@ -2,9 +2,10 @@
 # See also LICENSE.txt
 
 import xmlrpclib
+import urllib
 
 
-class BasicAuthTransport(xmlrpclib.Transport):
+class BasicAuthTransportBase:
 
     user = None
     password = None
@@ -24,9 +25,25 @@ class BasicAuthTransport(xmlrpclib.Transport):
         return host, extra_headers, x509
 
 
-def ServerProxy(base, user, password, transport=BasicAuthTransport):
+class BasicAuthTransport(BasicAuthTransportBase, xmlrpclib.Transport):
+    pass
+
+
+class SafeBasicAuthTransport(BasicAuthTransportBase, xmlrpclib.SafeTransport):
+    pass
+
+
+def ServerProxy(uri, user, password):
+    type, _ = urllib.splittype(uri)
+    if type == 'https':
+        transport = SafeBasicAuthTransport
+    elif type == 'http':
+        transport = BasicAuthTransport
+    else:
+        import pdb; pdb.set_trace() 
+        raise IOError('unsupported XML-RPC protocol')
     transport = transport(user, password)
-    return xmlrpclib.Server(base, transport=transport)
+    return xmlrpclib.Server(uri, transport=transport)
 
 
 Server = ServerProxy
